@@ -71,6 +71,9 @@ class ImageMetrics():
 
 		for i in range(len(self.left_grids)):
 			l_grid, r_grid = self.left_grids[i], self.right_grids[i]
+			if normalized:
+				l_grid = self.normalize_img(l_grid)
+				r_grid = self.normalize_img(r_grid)
 			l_diff = abs(self.calc_lum(l_grid) - self.calc_lum(r_grid))
 			luminance_difference.append(l_diff)	
 		return luminance_difference
@@ -84,14 +87,11 @@ class ImageMetrics():
 		weighted_B = .0722*img[:,:,0]
 		return np.mean(weighted_R + weighted_G + weighted_B)
 
-	def sharpness(self, normalized=False):
+	def sharpness(self):
 		sharpness_difference = []
 
 		for i in range(len(self.left_grids)):
 			l_grid, r_grid = self.left_grids[i], self.right_grids[i]
-			if normalized:
-				l_grid = self.normalize_img(l_grid)
-				r_grid = self.normalize_img(r_grid)
 			s_diff = abs(self.calc_sharpness(l_grid) - 
 			             self.calc_sharpness(r_grid))
 			sharpness_difference.append(s_diff)
